import * as Phoenix from "phoenix";
import { ConversationOptions, Entity, EntityEvent, EntityRef, SegmentDecoded, SpeakerLeft, SpeakerJoined, WordsDecoded, EntitiesRelationEvent } from "./types/conversation";
export declare class Conversation {
    private audioContext;
    private audioInterval;
    private audioSendInterval;
    private audioSourceConstraints;
    private channel;
    private conversationId;
    static readonly defaultCountry = "us";
    static readonly defaultModel = "en";
    private messageList;
    private pubsub;
    private recorder;
    private socket;
    private speakerList;
    static readonly validCountries: Set<string>;
    static readonly validModels: Set<string>;
    private wrapper;
    /**
     * @ignore
     */
    constructor(conversationId: string, identifier: string, socket: Phoenix.Socket, options: Required<ConversationOptions>);
    /**
     * Get the recording status of the conversation.
     *
     * @category Recording
     * @example
     * ```javascript
     * const uhlive = new Uhlive("my-token");
     * uhlive
     *     .join("my-conversation")
     *     .isRecording(); // true
     * ```
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * uhlive
     *     .join("my-conversation", {readonly: true})
     *     .isRecording(); // false
     * ```
     */
    isRecording(): boolean;
    /**
     * @ignore
     */
    leave(): void;
    /**
     * Subscribe to Conversation `onClose` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const conversation = uhlive.join("test");
     * conversation.onClose(() => {
     *   // Choose what to do when the conversation is closed.
     * })
     * ```
     */
    onClose(callback: () => void): Conversation;
    /**
     * This event is triggered when the specified entity has been found or the wildcard is used and any entity is found.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onEntityFound("LocationCity", (entity) => {
     *     // Do something with `entity`...
     * });
     * ```
     */
    onEntityFound(entityName: EntityEvent | "*", callback: (entity: Entity, entityName: EntityEvent) => void): Conversation;
    onEntityRelationFound(relationName: EntitiesRelationEvent | "*", callback: (entities: EntityRef[]) => void): Conversation;
    /**
     * Subscribe to Conversation `onError` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const conversation = uhlive.join("test");
     * conversation.onError((msg) => console.log(msg))
     * ```
     */
    onError(callback: (payload: any) => void): Conversation;
    /**
     * The `onSegmentDecoded` event is triggered when a final transcript is received.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onSegmentDecoded((transcript) => {
     *     // Do something with `transcript`...
     * });
     * ```
     */
    onSegmentDecoded(callback: (transcript: SegmentDecoded) => void): Conversation;
    /**
     * The `speaker_joined` event is triggered when a speaker join the conversation. It is sent to everyone except the speaker itself. Note that users connected in read-only mode (observers) don't emit this event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onSpeakerJoined((payload) => {
     *     // Do something with `payload`...
     * });
     * ```
     */
    onSpeakerJoined(callback: (payload: SpeakerJoined) => void): Conversation;
    /**
     * The `speaker_left` event is triggered when a speaker leaves, or more abruptly, closes its connection. This event is published after all remaining transcript events of this speaker have been published. Note that users connected in read-only mode (observers) don't emit this event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onSpeakerLeft((speaker) => {
     *     // Do something with `speaker`...
     * });
     * ```
     */
    onSpeakerLeft(callback: (payload: SpeakerLeft) => void): Conversation;
    /**
     * The `words_decoded` event is triggered when an interim transcript is received. Following `words_decoded` events for the same audio are susceptible to be different, until a final transcript is sent with the `segment_decoded` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-token");
     * const myConversation = uhlive.join("my-conversation");
     * myConversation.onWordsDecoded((transcript) => {
     *     // Do something with `transcript`...
     * });
     * ```
     */
    onWordsDecoded(callback: (transcript: WordsDecoded) => void): Conversation;
    private addEntityToMessage;
    private addOrUpdateMessage;
    private addSpeaker;
    private askForPermissions;
    private listenToEntityEvents;
    private sendMessage;
    private socketSend;
    private startRecording;
    private stopRecording;
    private validateConstructorParameters;
}
