import { Conversation } from "./conversation";
import { ConversationOptions } from "./types/conversation";
import { UhliveOptions } from "./types/uhlive";
export declare class Uhlive {
    private conversations;
    private identifier;
    private options;
    private pubsub;
    private socket;
    /**
     * Create an Uhlive instance by passing your private token and identifier.
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token", {
     *   timeout: 3,
     *   url: "wss://api.uh.live",
     * });
     * ```
     */
    constructor(identifier: string, token: string, options?: UhliveOptions);
    /**
     * Connect to the websocket.
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.connect();
     * ```
     */
    connect(): Uhlive;
    /**
     * Disconnect from the websocket.
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.connect();
     * uhlive.join("my-conversation");
     * uhlive.disconnect();
     * ```
     */
    disconnect(): Uhlive;
    /**
     * Join a conversation and start recording immediately.
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.connect();
     * uhlive.join("my-conversation", {
     *   speaker: "john",
     * });
     * uhlive.disconnect();
     * ```
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.connect();
     * uhlive.join("my-conversation", {
     *   ignoreEntities: ["NumberFound"],
     *   readonly: true,
     *   wrapper: "my-custom-wrapper",
     * });
     * uhlive.disconnect();
     * ```
     */
    join(conversationId: string, options?: ConversationOptions): Conversation;
    /**
     * Leave a conversation.
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.connect();
     * uhlive.join("my-conversation");
     * uhlive.leave("my-conversation");
     * uhlive.disconnect();
     * ```
     */
    leave(conversationId: string): Uhlive;
    /**
     * Leave all conversations at once.
     *
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.connect();
     * uhlive.join("my-conversation1");
     * uhlive.join("my-conversation2");
     * uhlive.leaveAllConversations();
     * uhlive.disconnect();
     * ```
     */
    leaveAllConversations(): Uhlive;
    /**
     * Subscribe to Uhlive `onClose` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.onClose(() => {
     *   // Choose what to do when the connection is closed.
     * });
     * ```
     */
    onClose(callback: () => void): Uhlive;
    /**
     * Subscribe to Uhlive `onError` event.
     *
     * @category Events
     * @example
     * ```js
     * const uhlive = new Uhlive("my-identifier", "my-token");
     * uhlive.onError(() => {
     *   // Choose what to do when we encounter an error.
     * });
     * ```
     */
    onError(callback: () => void): Uhlive;
    private static generateSpeakerId;
    private getBrowserLanguagesAndCountries;
    private getCountryFromBrowser;
    private getLocaleFromBrowser;
}
export { DecodingEvent, EntityEvent } from "./types/conversation";
export type { ConversationOptions, Entity, EntityAnnotation, SegmentDecoded, SegmentDecodedWord, SpeakerJoined, SpeakerLeft, WordsDecoded, } from "./types/conversation";
